@@ -19,7 +19,7 @@ def printStatement(file):
     print(statement)
 
 
-def lineChart(file,category):
+def lineplot(file,category):
     statement = pd.read_csv(file)
     statement.Breakdown = statement.Breakdown.str.replace(' ', '_')
     statement.Breakdown = statement.Breakdown.str.replace(',', '')
@@ -37,7 +37,7 @@ def lineChart(file,category):
     plt.figure(figsize=(20,9))
     sns.lineplot(data=plotData, x='index',y=category)
 
-def multiLinecharts(file,title):
+def multiLineplot(file,title):
 
     statement = pd.read_csv(file)
     statement.Breakdown = statement.Breakdown.str.replace(' ', '_')
@@ -148,5 +148,4 @@ def bulletChart(file,item):
     fig.update_layout(height = 250)
     
     fig.show()
-    
 
